diff --git a/WHATSNEW b/WHATSNEW
index dfc4f33da..48c39d73d 100644
--- a/WHATSNEW
+++ b/WHATSNEW
@@ -31,6 +31,10 @@ Changes that could break older environments:
compile against the current code base. If it still compiles, it will
probably not work as in Ant 1.5.1.
+* The and tasks now require Jakarta Commons Net instead
+ of the older ORO Netcomponents version. See
+ .
+
Fixed bugs:
-----------
* was not ignoring comment lines.
diff --git a/build.xml b/build.xml
index 8ce34077b..51257addb 100644
--- a/build.xml
+++ b/build.xml
@@ -253,7 +253,7 @@
-
+
@@ -381,8 +381,8 @@
-
-
+
@@ -783,7 +783,7 @@
-
+
@@ -892,10 +892,10 @@
-
-
+
section above.
www.judoscript.com/index.html |
- netcomponents.jar |
+ commons-net.jar |
ftp and telnet tasks |
- www.savarese.org/oro/downloads |
+ http://jakarta.apache.org/commons/net/index.html |
bcel.jar |
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/net/FTP.java b/src/main/org/apache/tools/ant/taskdefs/optional/net/FTP.java
index e7f57c623..3ba6aa584 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/net/FTP.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/net/FTP.java
@@ -53,9 +53,9 @@
*/
package org.apache.tools.ant.taskdefs.optional.net;
-import com.oroinc.net.ftp.FTPClient;
-import com.oroinc.net.ftp.FTPFile;
-import com.oroinc.net.ftp.FTPReply;
+import org.apache.commons.net.ftp.FTPClient;
+import org.apache.commons.net.ftp.FTPFile;
+import org.apache.commons.net.ftp.FTPReply;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedWriter;
@@ -1052,7 +1052,7 @@ public class FTP
log("login succeeded", Project.MSG_VERBOSE);
if (binary) {
- ftp.setFileType(com.oroinc.net.ftp.FTP.IMAGE_FILE_TYPE);
+ ftp.setFileType(org.apache.commons.net.ftp.FTP.IMAGE_FILE_TYPE);
if (!FTPReply.isPositiveCompletion(ftp.getReplyCode())) {
throw new BuildException("could not set transfer type: " +
ftp.getReplyString());
diff --git a/src/main/org/apache/tools/ant/taskdefs/optional/net/TelnetTask.java b/src/main/org/apache/tools/ant/taskdefs/optional/net/TelnetTask.java
index ad907e4c9..77e50dc0e 100644
--- a/src/main/org/apache/tools/ant/taskdefs/optional/net/TelnetTask.java
+++ b/src/main/org/apache/tools/ant/taskdefs/optional/net/TelnetTask.java
@@ -1,7 +1,7 @@
/*
* The Apache Software License, Version 1.1
*
- * Copyright (c) 2000,2002 The Apache Software Foundation. All rights
+ * Copyright (c) 2000,2002-2003 The Apache Software Foundation. All rights
* reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -54,7 +54,7 @@
package org.apache.tools.ant.taskdefs.optional.net;
-import com.oroinc.net.telnet.TelnetClient;
+import org.apache.commons.net.telnet.TelnetClient;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
@@ -305,8 +305,9 @@ public class TelnetTask extends Task {
/**
* This class handles the abstraction of the telnet protocol.
* Currently it is a wrapper around ORO's
* NetComponents
*/
public class AntTelnetClient extends TelnetClient {
/**
@@ -305,8 +305,9 @@ public class TelnetTask extends Task {
/**
* This class handles the abstraction of the telnet protocol.
- * Currently it is a wrapper around ORO's
- * NetComponents
+ * Currently it is a wrapper around Jakarta
+ * Commons Net.
*/
public class AntTelnetClient extends TelnetClient {